/*
 * callbacks.h
 */

#include <msp430.h>
#include <stdbool.h>
#include <stdint.h>
#include <HAL.h>
#include <GUI.h>
#include <Include/GUIComm.h>
#include <Include/QmathLib.h>


#ifndef INCLUDE_CALLBACKS_H_
#define INCLUDE_CALLBACKS_H_

// Global variables for the callbacks
volatile bool nSLEEP, nFAULT;
volatile bool nSLEEP_on_flag;
volatile bool nSLEEP_off_flag;

volatile _q qIncrement;
volatile uint8_t PwmSel;
volatile uint8_t PwmDuty;
volatile uint8_t NumPoles;


volatile uint8_t UartAddr;
volatile uint8_t UartData;
volatile bool UartRead, ReadFlag, ReadAllFlag;
volatile bool UartWrite, WriteFlag, WriteAllFlag;

//Initialize IC_STAT
volatile bool MTR_LOCK;
volatile bool IC_STAT_RSV;
volatile bool SPI_FLT;
volatile bool OCP;
volatile bool NPOR;
volatile bool OVP;
volatile bool OT;
volatile bool FAULT;

//Initialize STAT1
volatile bool OTW;
volatile bool OTS;
volatile bool OCP_HC;
volatile bool OCP_LC;
volatile bool OCP_HB;
volatile bool OCP_LB;
volatile bool OCP_HA;
volatile bool OCP_LA;

//Initialize STAT2
volatile bool STAT2_RSV2;
volatile bool OTP_ERR;
volatile bool STAT2_RSV1;
volatile bool AVDD_UV;
volatile bool VCP_UV;
volatile bool SPI_PARITY;
volatile bool SPI_SCLK_FLT;
volatile bool SPI_ADDR_FLT;

//Initialize CTRL1
volatile bool CTRL1_RSV5;
volatile bool CTRL1_RSV4;
volatile bool CTRL1_RSV3;
volatile bool CTRL1_RSV2;
volatile bool CTRL1_RSV1;
volatile bool REG_LOCK2;
volatile bool REG_LOCK1;
volatile bool REG_LOCK0;

//Initialize CTRL2
volatile bool CTRL2_RSV4;
volatile bool CTRL2_RSV3;
volatile bool SDO_MODE;
volatile bool CTRL2_RSV2;
volatile bool CTRL2_RSV1;
volatile bool PWM_MODE1;
volatile bool PWM_MODE0;
volatile bool CLR_FLT;

//Initialize CTRL3
volatile bool CTRL3_RSV3;
volatile bool CTRL3_RSV2;
volatile bool CTRL3_RSV1;
volatile bool PWM_100_DUTY_SEL;
volatile bool OVP_SEL;
volatile bool OVP_EN;
volatile bool SPI_FLT_REP;
volatile bool OTW_REP;

//Initialize CTRL4
volatile bool DRV_OFF;
volatile bool OCP_CBC;
volatile bool OCP_DEG1;
volatile bool OCP_DEG0;
volatile bool OCP_RETRY;
volatile bool CTRL4_RSV;
volatile bool OCP_MODE1;
volatile bool OCP_MODE0;

//Initialize CTRL5
volatile bool CTRL5_RSV6;
volatile bool ILIM_RECIR;
volatile bool CTRL5_RSV5;
volatile bool CTRL5_RSV4;
volatile bool CTRL5_RSV3;
volatile bool EN_ASR;
volatile bool CTRL5_RSV2;
volatile bool CTRL5_RSV1;

//Initialize CTRL6
volatile bool CTRL6_RSV8;
volatile bool CTRL6_RSV7;
volatile bool CTRL6_RSV6;
volatile bool CTRL6_RSV5;
volatile bool CTRL6_RSV4;
volatile bool CTRL6_RSV3;
volatile bool CTRL6_RSV2;
volatile bool CTRL6_RSV1;

//Initalize CTRL7
volatile bool CTRL7_RSV4;
volatile bool CTRL7_RSV3;
volatile bool CTRL7_RSV2;
volatile bool HALL_HYS;
volatile bool BRAKE_MODE;
volatile bool COAST;
volatile bool CTRL6_RSV1;
volatile bool DIR;

//Initialize CTRL8
volatile bool FGOUT_SEL1;     //default to FGOUT_SEL = 0b00 = 1 for H/W variant
volatile bool FGOUT_SEL0;
volatile bool CTRL8_RSV;
volatile bool MOTOR_LOCK_RETRY;
volatile bool MOTOR_LOCK_TDET1;
volatile bool MOTOR_LOCK_TDET0;
volatile bool MOTOR_LOCK_MODE1;
volatile bool MOTOR_LOCK_MODE0;

//Initialize CTRL9
volatile bool CTRL9_RSV5;
volatile bool CTRL9_RSV4;
volatile bool CTRL9_RSV3;
volatile bool CTRL9_RSV2;
volatile bool CTRL9_RSV1;
volatile bool ADVANCE_LVL2;
volatile bool ADVANCE_LVL1;
volatile bool ADVANCE_LVL0;

// Functions to receive data from GUI
extern void GUICallback_QMathData(char * string);
extern void GUICallback_nSLEEP(char * string);
extern void GUICallback_nFAULT(char * string);
extern void GUICallback_PwmSel(char * string);
extern void GUICallback_PwmDuty(char * string);
extern void GUICallback_NumPol(char * string);

extern void GUICallback_Addr(char * string);
extern void GUICallback_Data(char * string);
extern void GUICallback_Read(char * string);
extern void GUICallback_Write(char * string);
extern void GUICallback_ReadAll(char * string);
extern void GUICallback_WriteAll(char * string);

//SPI Register functions
//CTRL1
extern void GUICallback_Reg_Lock2(char * string);
extern void GUICallback_Reg_Lock1(char * string);
extern void GUICallback_Reg_Lock0(char * string);

//CTRL2
extern void GUICallback_Sdo_Mode(char * string);
extern void GUICallback_Pwm_Mode1(char * string);
extern void GUICallback_Pwm_Mode0(char * string);
extern void GUICallback_Clr_Flt(char * string);

//CTRL3
extern void GUICallback_Pwm_100_Duty_Sel(char * string);
extern void GUICallback_Ovp_Sel(char * string);
extern void GUICallback_Ovp_En(char * string);
extern void GUICallback_Spi_Flt_Rep(char * string);
extern void GUICallback_Otw_Rep(char * string);

//CTRL4
extern void GUICallback_Drv_Off(char * string);
extern void GUICallback_Ocp_Cbc(char * string);
extern void GUICallback_Ocp_Deg1(char * string);
extern void GUICallback_Ocp_Deg0(char * string);
extern void GUICallback_Ocp_Retry(char * string);
extern void GUICallback_Ocp_Mode1(char * string);
extern void GUICallback_Ocp_Mode0(char * string);

//CTRL5
extern void GUICallback_Ilim_Recir(char * string);
extern void GUICallback_En_Asr(char * string);

//CTRL6

//CTRL7
extern void GUICallback_Hall_Hys(char * string);
extern void GUICallback_Brake_Mode(char * string);
extern void GUICallback_Coast(char * string);
extern void GUICallback_Dir(char * string);

//CTRL8
extern void GUICallback_Fgout_Sel1(char * string);
extern void GUICallback_Fgout_Sel0(char * string);
extern void GUICallback_Motor_Lock_Retry(char * string);
extern void GUICallback_Motor_Lock_Tdet1(char * string);
extern void GUICallback_Motor_Lock_Tdet0(char * string);
extern void GUICallback_Motor_Lock_Mode1(char * string);
extern void GUICallback_Motor_Lock_Mode0(char * string);

//CTRL9
extern void GUICallback_Advance_Lvl2(char * string);
extern void GUICallback_Advance_Lvl1(char * string);
extern void GUICallback_Advance_Lvl0(char * string);

#endif /* INCLUDE_CALLBACKS_H_ */
